uNAC documentation
==================

Unified Natural Abundance Correction (uNAC) is a Python tool for isotope correction
using multiple backends (raw, isocor, ICT, isocorrector).

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   backends
   api
   developement
